
Figura
======

Figura is an *expressive high-level configuration language* based on Python syntax.

This is a python package for parsing and working with `Figura <http://figura.readthedocs.io/>`_ config files.

This library also includes an executable ``figura_print`` command, for processing
your figura config files and generating your configuration, printing it as a JSON structure.
The generated JSON-structured configuration can then be read by programs written in
any other language (using its JSON parser).

For more details, `Read the Figura Docs <http://figura.readthedocs.io/>`_.
